/*  Copyright (c) 2007-2008 Tomasz Moń <desowin@gmail.com>
 *  Copyright (c) 2004 Artur Gajda <ag@net13.org>
 *  Copyright (c) 2004 Jakub Zawadzki <darkjames@darkjames.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; under version 3 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses>.
 */

#include <libintl.h>
#include "commands.h"
#include "ui.h"
#include "net.h"
#include "riv.h"

//returns seconds arg from txt, for example 'te st' from '/away te st'
gchar *get_second_arg(const char *txt) {
    gchar **tmp;
    tmp = g_strsplit(txt, " ", 2);
    gchar *ret = NULL;
    if (tmp[1])
        ret = g_strdup(tmp[1]);
    g_strfreev(tmp);
    return ret;
}

void parse_command(char *txt) {
    gchar *arg = NULL;
    if (strncmp("/clear", txt, 6) == 0 || strncmp("/c", txt, 2) == 0) {
        gtk_text_buffer_set_text (buffer, VER, -1);
    } else if (strncmp("/help", txt, 4) == 0) {
        add_text(_("Command list:\n/about /clear (/c) /quit (/q) /help /me\n" \
                 "/topic (/t)\n" \
                 "/away (/a)\n" \
                 "/nick\n\n"));
    } else if (strncmp("/about", txt, 5) == 0) {
        add_text3("FG_NAVY", _("%s by Tomasz Moń\n"), VER);
        add_text(_("Original work by: Artur Gajda\n" \
                 "and Jakub 'darkjames' Zawadzki\n" \
                 "based on RivChat protocol\n" \
                 "http://www.rivchat.prv.pl\n" \
                 "http://griv.sourceforge.net\n\n"));
    } else if (strncmp("/version", txt, 8) == 0) {
        add_text(VERN);
    } else if (strncmp("/words", txt, 6) == 0) {
        arg = get_second_arg(txt);
        if (arg)
            slowa = atoi(arg);
    } else if (strncmp("/away", txt, 5) == 0 || strncmp("/a ", txt, 3) == 0) {
        arg = get_second_arg(txt);
        send_away(arg ? arg : "");
    } else if (strncmp("/me", txt, 3) == 0) {
        arg = get_second_arg(txt);
        if (arg && strlen(arg) > 0) send_me(arg);
    } else if (strncmp("/topic", txt, 6) == 0 || strncmp("/t ", txt, 3) == 0 ) {
        arg = get_second_arg(txt);
        if (arg && strlen(arg) > 0) {
            send_new_topic(arg);
        } else if (topic && strlen(topic) > 0)	{
            arg = g_strdup_printf("Topic: %s\n", topic);
            add_text(arg);
        }
    } else if (strncmp("/quit", txt, 5) == 0 || strncmp("/q", txt, 2) == 0) {
        griv_quit();
        return;
    } else if (strncmp("/nick", txt, 5) == 0) {
        arg = get_second_arg(txt);
        if (arg)
            change_nick(arg);
    } else
        add_text3(NULL, _("Unknown command: %s\n"), txt);

    if (arg)
        g_free(arg);
}
